@@ -58,7 +58,7 @@ oauth_flow_device <- function(client,
                               scope = NULL,
                               auth_params = list(),
                               token_params = list()) {
-  oauth_flow_check("device", client, interactive = TRUE)
+  oauth_flow_check("device", client, interactive = is_interactive())
 
   if (pkce) {
     code <- oauth_flow_auth_code_pkce()
@@ -117,7 +117,7 @@ oauth_flow_device_poll <- function(client, request, token_params) {
   while (Sys.time() < deadline) {
     for (i in 1:20) {
       cli::cli_progress_update()
-      sys_sleep(delay / 20)
+      Sys.sleep(delay / 20)
     }
 
     tryCatch(
